<?php
/**
 * WordPress session management.
 *
 * Standardizes WordPress session data and uses either database transients or in-memory caching
 * for storing user session information.
 *
 * @package WordPress
 * @subpackage Session
 * @since   3.7.0
 */

namespace BrewPixel\BrewPress\Session\includes;

/**
 * Return the current cache expire setting.
 *
 * @return int
 */
function WPSession_cache_expire() {
	$WPSession = WPSession::get_instance();

	return $WPSession->cache_expiration();
}

/**
 * Alias of WPSession_write_close()
 */
function WPSession_commit() {
	WPSession_write_close();
}

/**
 * Load a JSON-encoded string into the current session.
 *
 * @param string $data JSON encoded string.
 *
 * @return bool
 */
function WPSession_decode( $data ) {
	$WPSession = WPSession::get_instance();

	return $WPSession->json_in( $data );
}

/**
 * Encode the current session's data as a JSON string.
 *
 * @return string
 */
function WPSession_encode() {
	$WPSession = WPSession::get_instance();

	return $WPSession->json_out();
}

/**
 * Regenerate the session ID.
 *
 * @param bool $delete_old_session true or false to delete the old session values.
 *
 * @return bool
 */
function WPSession_regenerate_id( $delete_old_session = false ) {
	$WPSession = WPSession::get_instance();

	$WPSession->regenerate_id( $delete_old_session );

	return true;
}

/**
 * Start new or resume existing session.
 *
 * Resumes an existing session based on a value sent by the _WPSession cookie.
 *
 * @return bool
 */
function WPSession_start() {
	$WPSession = WPSession::get_instance();
	do_action( 'WPSession_start' );

	return $WPSession->session_started();
}
if ( ! defined( 'WP_CLI' ) || false === WP_CLI ) {
	add_action( 'plugins_loaded', 'WPSession_start' );
}

/**
 * Return the current session status.
 *
 * @return int
 */
function WPSession_status() {
	$WPSession = WPSession::get_instance();

	if ( $WPSession->session_started() ) {
		return PHP_SESSION_ACTIVE;
	}

	return PHP_SESSION_NONE;
}

/**
 * Unset all session variables.
 */
function WPSession_unset() {
	$WPSession = WPSession::get_instance();

	$WPSession->reset();
}

/**
 * Write session data and end session
 */
function WPSession_write_close() {
	$WPSession = WPSession::get_instance();

	$WPSession->write_data();
	do_action( 'WPSession_commit' );
}
if ( ! defined( 'WP_CLI' ) || false === WP_CLI ) {
	add_action( 'shutdown', 'WPSession_write_close' );
}

/**
 * Clean up expired sessions by removing data and their expiration entries from
 * the WordPress options table.
 *
 * This method should never be called directly and should instead be triggered as part
 * of a scheduled task or cron job.
 */
function WPSession_cleanup() {
	if ( defined( 'WP_SETUP_CONFIG' ) ) {
		return;
	}

	if ( ! defined( 'WP_INSTALLING' ) ) {
		/**
		 * Determine the size of each batch for deletion.
		 *
		 * @param int
		 */
		$batch_size = apply_filters( 'WPSession_delete_batch_size', 1000 );

		// Delete a batch of old sessions.
		WPSessionUtils::delete_old_sessions( $batch_size );
	}

	// Allow other plugins to hook in to the garbage collection process.
	do_action( 'WPSession_cleanup' );
}
add_action( 'WPSession_garbage_collection', 'WPSession_cleanup' );

/**
 * Register the garbage collector as a twice daily event.
 */
function WPSession_register_garbage_collection() {
	if ( ! wp_next_scheduled( 'WPSession_garbage_collection' ) ) {
		wp_schedule_event( time(), 'hourly', 'WPSession_garbage_collection' );
	}
}
add_action( 'wp', 'WPSession_register_garbage_collection' );
